@@ -12,7 +12,7 @@ def request_accesstoken(acc: str, pwd: str) -> str:
     response = requests.get(url, data)
     if response.status_code == 200:
         # print(response.json())
-        accessToken = response.json().get("token")
+        accessToken = response.json().get("accessToken")
         return accessToken
 
 
